@@ -1,12 +1,14 @@
 package App::SahUtils;
 
-our $DATE = '2021-07-29'; # DATE
-our $VERSION = '0.479'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-07-16'; # DATE
+our $DIST = 'App-SahUtils'; # DIST
+our $VERSION = '0.480'; # VERSION
+
 our %SPEC;
 
 $SPEC{get_sah_type} = {
@@ -346,7 +348,7 @@ App::SahUtils - Collection of CLI utilities for Sah and Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.479 of App::SahUtils (from Perl distribution App-SahUtils), released on 2021-07-29.
+This document describes version 0.480 of App::SahUtils (from Perl distribution App-SahUtils), released on 2022-07-16.
 
 =head1 SYNOPSIS
 
@@ -389,6 +391,10 @@ L<Sah> and L<Data::Sah>:
 
 =item * L<list-sah-filter-rule-modules>
 
+=item * L<list-sah-pschema-modules>
+
+=item * L<list-sah-pschemas-modules>
+
 =item * L<list-sah-schema-modules>
 
 =item * L<list-sah-schemas-modules>
@@ -810,14 +816,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-SahUti
 
 Source repository is at L<https://github.com/perlancar/perl-App-SahUtils>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-SahUtils>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Data::Sah>
@@ -826,11 +824,36 @@ L<Data::Sah>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-SahUtils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
